AppRadioGroup<T> class

Inheritance

Constructors

AppRadioGroup({Key? key, required FieldCubit<T> cubit, required String label, required List<T> values, required List<String> labels, bool toggleable = false, Color? activeColor, WidgetStateProperty<Color?>? fillColor, Color? hoverColor, WidgetStateProperty<Color?>? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, bool isThreeLine = false, bool? dense, ListTileControlAffinity controlAffinity = ListTileControlAffinity.platform, bool autofocus = false, EdgeInsetsGeometry? contentPadding, ShapeBorder? shape, Color? tileColor, Color? selectedTileColor, VisualDensity? visualDensity, bool? enableFeedback, double radioScaleFactor = 1.0, ListTileTitleAlignment? titleAlignment, bool? enabled, Color? radioBackgroundColor, BorderSide? radioSide, MouseCursor? mouseCursor, Widget subtitleBuilder(BuildContext context, int index)?, Widget secondaryBuilder(BuildContext context, int index)?})
const

Properties

activeColor Color?
final
autofocus bool
final
contentPadding EdgeInsetsGeometry?
final
controlAffinity ListTileControlAffinity
final
cubit FieldCubit<T>
final
dense bool?
final
enabled bool?
final
enableFeedback bool?
final
fillColor WidgetStateProperty<Color?>?
final
hashCode int
The hash code for this object.
no setterinherited
hoverColor Color?
final
isThreeLine bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
labels List<String>
final
materialTapTargetSize MaterialTapTargetSize?
final
mouseCursor MouseCursor?
final
overlayColor WidgetStateProperty<Color?>?
final
radioBackgroundColor Color?
final
radioScaleFactor double
final
radioSide BorderSide?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryBuilder Widget Function(BuildContext context, int index)?
final
selectedTileColor Color?
final
shape ShapeBorder?
final
splashRadius double?
final
subtitleBuilder Widget Function(BuildContext context, int index)?
Optional builder for custom subtitles or secondary widgets per index
final
tileColor Color?
final
titleAlignment ListTileTitleAlignment?
final
toggleable bool
final
values List<T>
final
visualDensity VisualDensity?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited